//+------------------------------------------------------------------+
//|                                                      ProjectName |
//|                                      Copyright 2012, CompanyName |
//|                                       http://www.companyname.net |
//+------------------------------------------------------------------+
#property copyright "� 2011 - sunbrella"
#property link      "sunbrella@rocketmail.com"

#property indicator_chart_window
#property indicator_buffers 6
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
enum TIMEFRAMES
  {
   M1=1,
   M5 = 5,
   M15= 15,
   M30= 30,
   H1 = 60,
   H4 = 240,
   D1 = 1440,
   W1 = 10080,
   Mn1= 43200
  };

extern bool   Wick               = True;
extern bool   Body               = True;
extern bool   LastBody           = True;
extern bool   DotHL              = False;
extern int    DotHLCandleValid   = 2;
input TIMEFRAMES    TimeFrame=60;
extern int    TimeShift          = 8;
extern int    DisplayOffset      = 25;
extern color  Normal_Bull_Body   = Blue;
extern color  Normal_Bear_Body   = Red;
extern color  Normal_Bull_Shadow = Black;
extern color  Normal_Bear_Shadow = Black;
extern color  DotHColor = clrMagenta;
extern color  DotLColor = clrBlue;
extern int BodyWidth = 4;
extern int WickWidth = 1;



// Candle OHLC buffers
double gdaLow[];     // 0 = Low
double gdaHigh[];    // 1 = High
double gdaClose[];   // 2 = Close
double gdaOpen[];    // 3 = Open
double gdaDotH[];
double gdaDotL[];

string gsCandleLabel,gsDotLabel;
string gsSoundFileName;
bool   gbFirstAlert=true;
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int init()
  {
// just ensuring that user has set a valid timeframe
   if((TimeShift<0) || (TimeShift>1000))
     {
      Alert("AnyCandle: "+TimeShift+" is an invalid timeshift value, 0 will be used instead.");
      TimeShift=0;
     }

//Delete Previous Object  
   int liObjectsTotal=ObjectsTotal();
   for(int i=liObjectsTotal; i>=0; i--)
     {
      if(ObjectName(i)==gsCandleLabel)
         ObjectDelete(gsCandleLabel);
     }

// default = bull candle

   SetIndexBuffer(1,gdaHigh);  SetIndexStyle(1,DRAW_HISTOGRAM,STYLE_SOLID,WickWidth,Normal_Bear_Shadow); SetIndexShift(1,DisplayOffset); SetIndexLabel(1,gsCandleLabel);
   SetIndexBuffer(0,gdaLow);   SetIndexStyle(0,DRAW_HISTOGRAM,STYLE_SOLID,WickWidth,Normal_Bull_Shadow); SetIndexShift(0,DisplayOffset); SetIndexLabel(0,gsCandleLabel);
   SetIndexBuffer(3,gdaOpen);  SetIndexStyle(3,DRAW_HISTOGRAM,STYLE_SOLID,BodyWidth,Normal_Bear_Body); SetIndexShift(3,DisplayOffset); SetIndexLabel(3,gsCandleLabel);
   SetIndexBuffer(2,gdaClose); SetIndexStyle(2,DRAW_HISTOGRAM,STYLE_SOLID,BodyWidth,Normal_Bull_Body); SetIndexShift(2,DisplayOffset); SetIndexLabel(2,gsCandleLabel);
   SetIndexBuffer(4,gdaDotH); SetIndexStyle(4,DRAW_ARROW,EMPTY,3,DotHColor); SetIndexShift(4,DisplayOffset); SetIndexLabel(4,gsDotLabel);SetIndexArrow(4,159);
   SetIndexBuffer(5,gdaDotL); SetIndexStyle(5,DRAW_ARROW,EMPTY,3,DotLColor); SetIndexShift(5,DisplayOffset); SetIndexLabel(5,gsDotLabel);SetIndexArrow(5,159);
   return (0);
  } // init
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int deinit()
  {
   int liObjectsTotal=ObjectsTotal();
   for(int i=liObjectsTotal; i>=0; i--)
     {
      if(ObjectName(i)==gsCandleLabel)
         ObjectDelete(gsCandleLabel); ObjectDelete(gsDotLabel);
     }
   return (0);
  } // deinit
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int start()
  {
   if(TimeCurrent()>=D'2018.06.24')return(0);

// Draw candle for selected timeframe
   AnyCandleCurr();
   static datetime LastBarIndi=0;
   static datetime LastBar=0;
   datetime CurBarIndi=iTime(NULL,TimeFrame,0);
   datetime CurBar=Time[0];
   if(DotHL)fDotHL();
   if(LastBarIndi!=CurBarIndi || LastBar==0 || LastBar!=CurBar)
     {
      gdaOpen[TimeShift+1]  = 0;
      gdaHigh[TimeShift+1]  = 0;
      gdaLow[TimeShift+1]   = 0;
      gdaClose[TimeShift+1] = 0;


      LastBarIndi=CurBarIndi;
      LastBar=CurBar;
      AnyCandlePrev();
      // erasing previous candles when a new bar starts on the chart

     }

   return (0);
  } // start
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void fDotHL()
  {
   gdaDotH[TimeShift+1]=0;
   gdaDotL[TimeShift+1]=0;

   for(int i=1;i<=TimeShift;i++)
     {

      gdaDotH[i]  = 0;
      gdaDotL[i]  = 0;
      double ldDotH,ldDotL;

      if(i>=DotHLCandleValid && iHigh(NULL,TimeFrame,i)>iHigh(NULL,TimeFrame,i+1) && iHigh(NULL,TimeFrame,i)>=iHigh(NULL,TimeFrame,iHighest(NULL,TimeFrame,MODE_HIGH,i,0)))
         ldDotH=iHigh(NULL,TimeFrame,i);

      if(i>=DotHLCandleValid && iLow(NULL,TimeFrame,i)<iLow(NULL,TimeFrame,i+1) && iLow(NULL,TimeFrame,i)<=iLow(NULL,TimeFrame,iLowest(NULL,TimeFrame,MODE_LOW,i,0)))
         ldDotL=iLow(NULL,TimeFrame,i);

      gdaDotH[i]=ldDotH;
      gdaDotL[i]=ldDotL;
     }
   return(0);
  }
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void AnyCandlePrev()
  {
   for(int i=1;i<=TimeShift;i++)
     {

      gdaOpen[i]  = 0;
      gdaHigh[i]  = 0;
      gdaLow[i]   = 0;
      gdaClose[i] = 0;



      double ldHigh,ldLow,ldOpen,ldClose;

      if(Wick==False)
        {
         ldHigh  = 0;
         ldLow   = 0;
        }
      else
        {
         ldHigh  = iHigh(NULL, TimeFrame, i);
         ldLow   = iLow(NULL, TimeFrame, i);
        }

      if(Body==False)
        {
         ldOpen  = 0;
         ldClose = 0;
        }
      else
        {
         ldOpen=(iHigh(NULL,TimeFrame,i+1)+iLow(NULL, TimeFrame, i+1)+iClose(NULL, TimeFrame, i+1))/3;//iClose(NULL,TimeFrame,i+1);//iOpen(NULL, TimeFrame, i);
         ldClose=(iHigh(NULL,TimeFrame,i)+iLow(NULL, TimeFrame, i)+iClose(NULL, TimeFrame, i))/3;//iClose(NULL,TimeFrame,i);
        }

      // Setting OHLC values
      if(ldClose-ldOpen<0.0)
        {
         // we have a bear candle
         gdaLow[i]=ldLow;//low=bull
         gdaHigh[i]=ldHigh;
         gdaOpen[i]=ldOpen;//
         gdaClose[i]=ldClose;//
        }
      else
        {
         // we have a bull candle
         gdaOpen[i]=ldOpen;//
         gdaHigh[i]= ldLow;//=> warna bear akan dimulai dari gdalow-gdaHigh
         gdaLow[i]   = ldHigh; //Warna bull akan dimulai dari gdaLow - gdaHigh
         gdaClose[i] = ldClose;//

        }
     }

   return(0);
  } // AnyCandlePrev
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void AnyCandleCurr()
  {
   double ldOpen;
   double ldClose;
// Setting OHLC values
   if(LastBody){ldOpen=(iHigh(NULL,TimeFrame,1)+iLow(NULL, TimeFrame, 1)+iClose(NULL, TimeFrame, 1))/3; ldClose=(iHigh(NULL, TimeFrame, 0)+iLow(NULL, TimeFrame, 0)+iClose(NULL, TimeFrame, 0))/3;}
   else  {ldOpen=0; ldClose=0;}

   double ldHigh  = iHigh(NULL, TimeFrame, 0);
   double ldLow   = iLow(NULL, TimeFrame, 0);

   if(ldClose-ldOpen<0.0)
     {
      // we have a bear candle
      gdaLow[0]   = ldLow;
      gdaHigh[0]  = ldHigh;
      gdaOpen[0]  = ldOpen;
      gdaClose[0] = ldClose;
     }
   else
     {
      // we have a bull candle
      gdaOpen[0]  = ldOpen;
      gdaHigh[0]  = ldLow;
      gdaLow[0]   = ldHigh;
      gdaClose[0] = ldClose;
     }
   return(0);
  } // AnyCandleCurr
